==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/phone_call.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

PhoneCall = Union[raw.types.PhoneCall, raw.types.PhoneCallAccepted, raw.types.PhoneCallDiscarded, raw.types.PhoneCallEmpty, raw.types.PhoneCallRequested, raw.types.PhoneCallWaiting]


# noinspection PyRedeclaration
class PhoneCall(TLObject):  # type: ignore
    """This base type has 6 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`PhoneCall <pyrogram.raw.types.PhoneCall>`
            - :obj:`PhoneCallAccepted <pyrogram.raw.types.PhoneCallAccepted>`
            - :obj:`PhoneCallDiscarded <pyrogram.raw.types.PhoneCallDiscarded>`
            - :obj:`PhoneCallEmpty <pyrogram.raw.types.PhoneCallEmpty>`
            - :obj:`PhoneCallRequested <pyrogram.raw.types.PhoneCallRequested>`
            - :obj:`PhoneCallWaiting <pyrogram.raw.types.PhoneCallWaiting>`
    """

    QUALNAME = "pyrogram.raw.base.PhoneCall"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/phone_call.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

PhoneCall = Union[raw.types.PhoneCall, raw.types.PhoneCallAccepted, raw.types.PhoneCallDiscarded, raw.types.PhoneCallEmpty, raw.types.PhoneCallRequested, raw.types.PhoneCallWaiting]


# noinspection PyRedeclaration
class PhoneCall:  # type: ignore
    """This base type has 6 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`PhoneCall <pyrogram.raw.types.PhoneCall>`
            - :obj:`PhoneCallAccepted <pyrogram.raw.types.PhoneCallAccepted>`
            - :obj:`PhoneCallDiscarded <pyrogram.raw.types.PhoneCallDiscarded>`
            - :obj:`PhoneCallEmpty <pyrogram.raw.types.PhoneCallEmpty>`
            - :obj:`PhoneCallRequested <pyrogram.raw.types.PhoneCallRequested>`
            - :obj:`PhoneCallWaiting <pyrogram.raw.types.PhoneCallWaiting>`
    """

    QUALNAME = "pyrogram.raw.base.PhoneCall"
